---
name: "\U000023F3 Installation Problem"
about: For the problem that you faced when installing doccano which none of the suggestions in the docs and other issues helped

---

<!-- Before submitting an issue, make sure to check the docs and closed issues and FAQ to see if any of the solutions work for you. https://github.com/doccano/doccano/wiki/Frequently-Asked-Questions -->

How to reproduce the problem
---------
<!-- Include the details of how the problem occurred. Which option did you choose to install doccano? Did you come across an error? What else did you try? -->

```bash
# copy-paste the error message here
```

Your Environment
---------
<!-- Include details of your environment.-->
*   Operating System:
*   Python Version Used:
*   When you install doccano:
*   How did you install doccano (Heroku button etc):
